@@ -604,6 +604,22 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
       "${sudo}chmod -v a+w avatar background file",'__display__');
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}chgrp -v ec2-user avatar background file",'__display__');
+   my $fa_builddir=fullauto_builddir($local,$sudo);
+   my $ignore='';
+   ($ignore,$stdout)=$local->cmd("${sudo}cp -v $fa_builddir/installer/".
+      'fullauto_clickable_image.png ~','__display__');
+   ($ignore,$stdout)=$local->cmd($sudo.
+      'chmod -v 777 fullauto_clickable_image.png','__display__');
+   ($stdout,$stderr)=$handle->cwd('~');
+   ($stdout,$stderr)=$handle->put('fullauto_clickable_image.png');
+   ($stdout,$stderr)=$handle->cmd($sudo.
+      'chmod -v 777 fullauto_clickable_image.png','__display__');
+   ($stdout,$stderr)=$handle->cwd('~');
+   my $sd='/var/www/gnusocial/theme/neo-gnu';
+   ($stdout,$stderr)=$handle->cmd($sudo.
+      "mv -vf fullauto_clickable_image.png $sd",'__display__');
+   ($stdout,$stderr)=$local->cmd($sudo.
+      "rm -rvf fullauto_clickable_image.png",'__display__');
    #
    # echo-ing/streaming files over ssh can be tricky. Use echo -e
    #          and replace these characters with thier HEX
